@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use Fey::Exceptions qw(param_error);
 use Fey::Table;
@@ -101,10 +101,6 @@ sub primary_key {
 
 sub is_alias {1}
 
-sub sql_for_select_clause {
-    return $_[1]->quote_identifier( $_[0]->alias_name() ) . '.*';
-}
-
 sub sql_with_alias {
     return (  $_[1]->quote_identifier( $_[0]->table()->name() ) . ' AS '
             . $_[1]->quote_identifier( $_[0]->alias_name() ) );
@@ -122,13 +118,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Fey::Table::Alias - Represents an alias for a table
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -214,16 +212,25 @@ roles.
 
 See L<Fey> for details on how to report bugs.
 
+Bugs may be submitted at L<https://github.com/ap/Fey/issues>.
+
+=head1 SOURCE
+
+The source code repository for Fey can be found at L<https://github.com/ap/Fey>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 - 2015 by Dave Rolsky.
+This software is Copyright (c) 2011 - 2025 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
